@@ -64,10 +64,10 @@ def init_db(*args, **kwargs) -> Engine:
         _DB_CTX = DBCtx(connect=connect, prepared=prepared)
 
     if pool_size > 0:
-        logger.info("Inited db engine <%s> of %s with driver: '%s' and pool size: %d." % (hex(id(_DB_CTX)), engine.value,
+        logger.info("Inited db <%s> of %s with driver: '%s' and pool size: %d." % (hex(id(_DB_CTX)), engine.value,
                                                                                           driver_name, pool_size))
     else:
-        logger.info("Inited db engine <%s> of %s with driver: '%s'." % (hex(id(_DB_CTX)), engine.value, driver_name))
+        logger.info("Inited db <%s> of %s with driver: '%s'." % (hex(id(_DB_CTX)), engine.value, driver_name))
 
     return engine
 
